@@ -8,8 +8,12 @@ from sklearn.utils.validation import check_is_fitted
 from sklearn.utils import deprecated
 
 from feature_engine.dataframe_checks import _is_dataframe, _check_input_matches_training_df
-from feature_engine.variable_manipulation import _find_categorical_variables, _define_variables, \
-    _find_numerical_variables
+from feature_engine.variable_manipulation import (
+    _find_categorical_variables,
+    _define_variables,
+    _find_numerical_variables,
+    _define_numerical_dict
+)
 from feature_engine.base_transformers import BaseImputer
 
 
@@ -255,10 +259,16 @@ class ArbitraryNumberImputer(BaseImputer):
 
     variables : list, default=None
         The list of variables to be imputed. If None, the imputer will find and
-        select all numerical type variables.
+        select all numerical type variables. Attribute is used only if `imputer_dict`
+        attribute is None.
+
+    imputer_dict: dict, default=None
+        The dictionary of variables and their arbitrary numbers. If imputer_dict is not None,
+        it has to be dictionary with all values of integer or float type.
+        If None, `variables` attribute is used for imputation.
     """
 
-    def __init__(self, arbitrary_number=999, variables=None):
+    def __init__(self, arbitrary_number=999, variables=None, imputer_dict=None):
 
         if isinstance(arbitrary_number, int) or isinstance(arbitrary_number, float):
             self.arbitrary_number = arbitrary_number
@@ -267,6 +277,8 @@ class ArbitraryNumberImputer(BaseImputer):
 
         self.variables = _define_variables(variables)
 
+        self.imputer_dict = _define_numerical_dict(imputer_dict)
+
     def fit(self, X, y=None):
         """
         Checks that the variables are numerical.
@@ -285,10 +297,16 @@ class ArbitraryNumberImputer(BaseImputer):
         X = _is_dataframe(X)
 
         # find or check for numerical variables
-        self.variables = _find_numerical_variables(X, self.variables)
+        if self.imputer_dict:
+            self.variables = _find_numerical_variables(X, self.imputer_dict.keys())
+        else:
+            self.variables = _find_numerical_variables(X, self.variables)
 
         # create the imputer dictionary
-        self.imputer_dict_ = {var: self.arbitrary_number for var in self.variables}
+        if self.imputer_dict:
+            self.imputer_dict_ = self.imputer_dict
+        else:
+            self.imputer_dict_ = {var: self.arbitrary_number for var in self.variables}
 
         self.input_shape_ = X.shape
 
